"""
Class that implements pyFoamPlotRunner
"""

from PyFoamApplication import PyFoamApplication

from PyFoam.Execution.GnuplotRunner import GnuplotRunner

class PlotRunner(PyFoamApplication):
    def __init__(self):
        description="""
        runs an OpenFoam solver needs the usual 3 arguments (<solver>
        <directory> <case>) and passes them on (plus additional arguments).
        Output is sent to stdout and a logfile inside the case directory
        (PyFoamSolver.logfile) Information about the residuals is output as
        graphs
        """
        PyFoamApplication.__init__(self,description=description)

    def addOptions(self):
        self.parser.add_option("--frequency",type="float",dest="frequency",default=1.,help="The frequency with which output should be generated (in seconds)")
        self.parser.add_option("--persist",action="store_true",dest="persist",default=True,help="Gnuplot windows stay after interrupt")
        self.parser.add_option("--non-persist",action="store_false",dest="persist",help="Gnuplot windows close after interrupt")
        self.parser.add_option("--no-linear",action="store_false",default=True,dest="linear",help="Don't plot the linear solver convergence")
        self.parser.add_option("--no-continuity",action="store_false",default=True,dest="cont",help="Don't plot the continuity info")
        self.parser.add_option("--no-bound",action="store_false",default=True,dest="bound",help="Don't plot the bounding of variables")
        self.parser.add_option("--with-iterations",action="store_true",default=False,dest="iterations",help="Plot the number of iterations of the linear solver")
        self.parser.add_option("--with-courant",action="store_true",default=False,dest="courant",help="Plot the courant-numbers of the flow")
        self.parser.add_option("--with-execution",action="store_true",default=False,dest="execution",help="Plot the execution time of each time-step")
        self.parser.add_option("--with-all",action="store_true",default=False,dest="withAll",help="Switch all possible plots on")
        self.parser.add_option("--custom-regexp",action="store",default=None,dest="customRegex",help="Add a custom regular expression to be plotted")
        
    def run(self):
        if self.opts.withAll:
            self.opts.linear=True
            self.opts.cont=True
            self.opts.bound=True
            self.opts.iterations=True
            self.opts.courant=True
            self.opts.execution=True
    
        run=GnuplotRunner(argv=self.parser.getArgs(),smallestFreq=self.opts.frequency,persist=self.opts.persist,plotLinear=self.opts.linear,plotCont=self.opts.cont,plotBound=self.opts.bound,plotIterations=self.opts.iterations,plotCourant=self.opts.courant,plotExecution=self.opts.execution,customRegexp=self.opts.customRegex)
            
        run.start()
